@@ -1,17 +1,23 @@
-import { configValues, configFileTypes as types, answerFilePrefixes, resourceConstants } from "../components/HostedEngineSetup/constants"
+import {
+    configValues, configFileTypes as types, answerFilePrefixes, resourceConstants,
+    resourceConstants as constants
+} from "../components/HostedEngineSetup/constants"
 import classNames from 'classnames'
 import Validation from '../components/HostedEngineSetup/Validation'
 
 export class HeSetupModel {
     constructor() {
         this.model = this.getBaseHeSetupModel();
+        this.assignVmUUID();
 
         this.getBaseHeSetupModel = this.getBaseHeSetupModel.bind(this);
         this.addGlusterValues = this.addGlusterValues.bind(this);
         this.addValuesToModel = this.addValuesToModel.bind(this);
+        this.setDefaultValues = this.setDefaultValues.bind(this);
         this.setBooleanValues = this.setBooleanValues.bind(this);
         this.setBooleanValue = this.setBooleanValue.bind(this);
         this.getAnsFileProperty = this.getAnsFileProperty.bind(this);
+        this.assignVmUUID = this.assignVmUUID.bind(this);
     }
 
     getBaseHeSetupModel() {
@@ -66,6 +72,54 @@ export class HeSetupModel {
                     uiStage: "",
                     useInAnswerFile: true,
                     required: false
+                },
+                localVmDirPath: {
+                    name: "LOCAL_VM_DIR_PATH",
+                    ansibleVarName: "LOCAL_VM_DIR_PATH",
+                    ansiblePhasesUsed: [1],
+                    description: "LOCAL_VM_DIR_PATH",
+                    value: "/var/tmp",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                localVmDirPrefix: {
+                    name: "LOCAL_VM_DIR_PREFIX",
+                    ansibleVarName: "LOCAL_VM_DIR_PREFIX",
+                    ansiblePhasesUsed: [1],
+                    description: "LOCAL_VM_DIR_PREFIX",
+                    value: "localvm",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                localVmDir: {
+                    name: "LOCAL_VM_DIR",
+                    ansibleVarName: "LOCAL_VM_DIR",
+                    ansiblePhasesUsed: [2,3],
+                    description: "LOCAL_VM_DIR",
+                    value: "localvm",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                discard: {
+                    name: "discard",
+                    ansibleVarName: "DISCARD",
+                    ansiblePhasesUsed: [2],
+                    description: "Discard",
+                    value: false,
+                    type: types.BOOLEAN,
+                    showInReview: false,
+                    uiStage: "",
+                    useInAnswerFile: false,
+                    required: false
                 }
             },
             storage: {
@@ -74,7 +128,7 @@ export class HeSetupModel {
                     ansibleVarName: "DOMAIN_TYPE",
                     ansiblePhasesUsed: [2, 3],
                     description: "Storage Type",
-                    value: "nfs3",
+                    value: "nfs",
                     type: types.STRING,
                     showInReview: true,
                     uiStage: "Storage",
@@ -83,6 +137,8 @@ export class HeSetupModel {
                 },
                 imgSizeGB: {
                     name: "imgSizeGB",
+                    ansibleVarName: "DISK_SIZE",
+                    ansiblePhasesUsed: [3],
                     description: "Disk Size (GB)",
                     value: "50",
                     type: types.STRING,
@@ -115,9 +171,21 @@ export class HeSetupModel {
                     useInAnswerFile: true,
                     required: true
                 },
+                storageAddress: {
+                    name: "storageAddress",
+                    ansibleVarName: "STORAGE_DOMAIN_ADDRESS",
+                    ansiblePhasesUsed: [2],
+                    description: "Storage Address",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "Storage",
+                    useInAnswerFile: false,
+                    required: false
+                },
                 storageDomainConnection: {
                     name: "storageDomainConnection",
-                    ansibleVarName: "STORAGE",
+                    ansibleVarName: "STORAGE_DOMAIN_CONNECTION",
                     ansiblePhasesUsed: [3],
                     description: "Storage Domain Connection",
                     value: "",
@@ -127,10 +195,22 @@ export class HeSetupModel {
                     useInAnswerFile: false,
                     required: true
                 },
+                storage: {
+                    name: "storage",
+                    ansibleVarName: "STORAGE",
+                    ansiblePhasesUsed: [3],
+                    description: "Storage Domain Connection",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "Storage",
+                    useInAnswerFile: false,
+                    required: false
+                },
                 mntOptions: {
                     name: "mntOptions",
                     ansibleVarName: "MOUNT_OPTIONS",
-                    ansiblePhasesUsed: [2],
+                    ansiblePhasesUsed: [2,3],
                     description: "Mount Options",
                     value: "",
                     type: types.STRING,
@@ -139,6 +219,18 @@ export class HeSetupModel {
                     useInAnswerFile: true,
                     required: false
                 },
+                nfsVersion: {
+                    name: "nfsVersion",
+                    ansibleVarName: "NFS_VERSION",
+                    ansiblePhasesUsed: [2,3],
+                    description: "NFS Version",
+                    value: "3",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "Storage",
+                    useInAnswerFile: false,
+                    required: false
+                },
                 iSCSIPortalUser: {
                     name: "iSCSIPortalUser",
                     ansibleVarName: "ISCSI_USERNAME",
@@ -163,8 +255,34 @@ export class HeSetupModel {
                     useInAnswerFile: false,
                     required: false
                 },
+                iSCSIDiscoverUser: {
+                    name: "iSCSIDiscoverUser",
+                    ansibleVarName: "ISCSI_DISCOVER_USERNAME",
+                    ansiblePhasesUsed: [2, 3],
+                    description: "Discovery User",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "Storage",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                iSCSIDiscoverPassword: {
+                    name: "iSCSIDiscoverPassword",
+                    ansibleVarName: "ISCSI_DISCOVER_PASSWORD",
+                    ansiblePhasesUsed: [2, 3],
+                    description: "Discovery Password",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "Storage",
+                    useInAnswerFile: false,
+                    required: false
+                },
                 iSCSIPortalIPAddress: {
                     name: "iSCSIPortalIPAddress",
+                    ansibleVarName: "ISCSI_PORTAL_ADDR",
+                    ansiblePhasesUsed: [3],
                     description: "Portal IP Address",
                     value: "",
                     type: types.STRING,
@@ -175,9 +293,21 @@ export class HeSetupModel {
                     regex: Validation.ipAddress,
                     errorMsg: "Invalid format for IP address"
                 },
+                iSCSIIPTPGT: {
+                    name: "iSCSIIPTPGT",
+                    ansibleVarName: "ISCSI_IP_TPGT",
+                    ansiblePhasesUsed: [3],
+                    description: "iSCSI IP TPGT",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "Storage",
+                    useInAnswerFile: false,
+                    required: false
+                },
                 iSCSIPortalPort: {
                     name: "iSCSIPortalPort",
-                    ansibleVarName: "ISCSI_PORT",
+                    ansibleVarName: "ISCSI_PORTAL_PORT",
                     ansiblePhasesUsed: [2, 3],
                     description: "Portal Port",
                     value: "3260",
@@ -204,7 +334,7 @@ export class HeSetupModel {
                 LunID: {
                     name: "LunID",
                     ansibleVarName: "LUN_ID",
-                    ansiblePhasesUsed: [2],
+                    ansiblePhasesUsed: [2,3],
                     description: "Destination LUN",
                     value: "",
                     type: types.STRING,
@@ -227,6 +357,8 @@ export class HeSetupModel {
                 },
                 bridgeName: {
                     name: "bridgeName",
+                    ansibleVarName: "BRIDGE",
+                    ansiblePhasesUsed: [3],
                     description: "Bridge Name",
                     value: "ovirtmgmt",
                     type: types.STRING,
@@ -264,12 +396,24 @@ export class HeSetupModel {
                     ansibleVarName: "FQDN",
                     ansiblePhasesUsed: [1, 2, 3],
                     description: "Engine FQDN",
-                    value: "ovirt-engine.localdomain",
+                    value: "",
                     type: types.STRING,
                     showInReview: true,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: true
+                },
+                host_name: {
+                    name: "host_name",
+                    ansibleVarName: "HOST_ADDRESS",
+                    ansiblePhasesUsed: [1,3],
+                    description: "Host IP or FQDN",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
                 }
             },
             vm: {
@@ -288,13 +432,61 @@ export class HeSetupModel {
                     ansibleVarName: "VCPUS",
                     ansiblePhasesUsed: [1, 3],
                     description: "Number of Virtual CPUs",
-                    value: "2",
+                    value: "1",
                     type: types.STRING,
                     showInReview: true,
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: true,
-                    range: {min: 2, max: 2}
+                    range: {min: 1, max: 1}
+                },
+                maxVCpus: {
+                    name: "maxVCpus",
+                    ansibleVarName: "MAXVCPUS",
+                    ansiblePhasesUsed: [1,3],
+                    description: "Maximum Number of Virtual CPUs",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                cpuSockets: {
+                    name: "cpuSockets",
+                    ansibleVarName: "CPU_SOCKETS",
+                    ansiblePhasesUsed: [1,3],
+                    description: "Number of CPU Sockets",
+                    value: "1",
+                    type: types.INTEGER,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                emulatedMachine: {
+                    name: "emulatedMachine",
+                    ansibleVarName: "EMULATED_MACHINE",
+                    ansiblePhasesUsed: [1,3],
+                    description: "Emulated Machine",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                localVmUUID: {
+                    name: "localVmUUID",
+                    ansibleVarName: "VM_UUID",
+                    ansiblePhasesUsed: [1],
+                    description: "Local VM UUID",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
                 },
                 vmMACAddr: {
                     name: "vmMACAddr",
@@ -310,12 +502,25 @@ export class HeSetupModel {
                     regex: Validation.macAddress,
                     errorMsg: "Invalid format for MAC address"
                 },
+                vmIpPrefix: {
+                    name: "vmIpPrefix",
+                    ansibleVarName: "VM_IP_PREFIX",
+                    ansiblePhasesUsed: [3],
+                    description: "VM IP Prefix",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: true,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
                 vmMemSizeMB: {
                     name: "vmMemSizeMB",
                     ansibleVarName: "MEM_SIZE",
                     ansiblePhasesUsed: [1, 3],
                     description: "Memory Size (MB)",
                     value: "4096",
+                    unit: "MB",
                     type: types.INTEGER,
                     showInReview: true,
                     uiStage: "VM",
@@ -335,6 +540,8 @@ export class HeSetupModel {
                 },
                 cloudinitVMStaticCIDR: {
                     name: "cloudinitVMStaticCIDR",
+                    ansibleVarName: "VM_IP_ADDR",
+                    ansiblePhasesUsed: [3],
                     description: "IP Address",
                     value: "",
                     type: types.STRING,
@@ -347,6 +554,8 @@ export class HeSetupModel {
                 },
                 cloudinitVMDNS: {
                     name: "cloudinitVMDNS",
+                    ansibleVarName: "DNS_ADDR",
+                    ansiblePhasesUsed: [3],
                     description: "DNS Servers",
                     value: [""],
                     type: types.STRING,
@@ -390,7 +599,7 @@ export class HeSetupModel {
                 ovfArchive: {
                     name: "ovfArchive",
                     ansibleVarName: "APPLIANCE_OVA",
-                    ansiblePhasesUsed: [1],
+                    ansiblePhasesUsed: [1,3],
                     description: "Appliance File Path",
                     value: "",
                     type: types.STRING,
@@ -401,8 +610,8 @@ export class HeSetupModel {
                 },
                 cloudinitInstanceHostName: {
                     name: "cloudinitInstanceHostName",
-                    ansibleVarName: "",
-                    ansiblePhasesUsed: [],
+                    ansibleVarName: "CLOUD_INIT_HOST_NAME",
+                    ansiblePhasesUsed: [1,3],
                     description: "Engine VM Host Name",
                     value: "ovirt-engine",
                     type: types.STRING,
@@ -414,7 +623,7 @@ export class HeSetupModel {
                 cloudinitInstanceDomainName: {
                     name: "cloudinitInstanceDomainName",
                     ansibleVarName: "CLOUD_INIT_DOMAIN_NAME",
-                    ansiblePhasesUsed: [1],
+                    ansiblePhasesUsed: [1,3],
                     description: "Engine VM Domain",
                     value: "localdomain",
                     type: types.STRING,
@@ -446,7 +655,7 @@ export class HeSetupModel {
                 cloudinitRootPwd: {
                     name: "cloudinitRootPwd",
                     ansibleVarName: "APPLIANCE_PASSWORD",
-                    ansiblePhasesUsed: [1],
+                    ansiblePhasesUsed: [1,3],
                     description: "Root password",
                     value: "",
                     type: types.STRING,
@@ -468,7 +677,7 @@ export class HeSetupModel {
                 rootSshPubkey: {
                     name: "rootSshPubkey",
                     ansibleVarName: "ROOT_SSH_PUBKEY",
-                    ansiblePhasesUsed: [1],
+                    ansiblePhasesUsed: [1,3],
                     description: "Root User SSH Public Key",
                     value: "",
                     type: types.STRING,
@@ -492,7 +701,7 @@ export class HeSetupModel {
                 cloudinitVMETCHOSTS: {
                     name: "cloudinitVMETCHOSTS",
                     ansibleVarName: "VM_ETC_HOSTS",
-                    ansiblePhasesUsed: [1],
+                    ansiblePhasesUsed: [1,3],
                     description: "Add Lines to /etc/hosts",
                     value: true,
                     type: types.BOOLEAN,
@@ -500,6 +709,102 @@ export class HeSetupModel {
                     uiStage: "VM",
                     useInAnswerFile: true,
                     required: false
+                },
+                cloudinitHostIP: {
+                    name: "cloudinitHostIP",
+                    ansibleVarName: "HOST_IP",
+                    ansiblePhasesUsed: [1,3],
+                    description: "Host IP Address",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                cdromUUID: {
+                    name: "cdromUUID",
+                    ansibleVarName: "CDROM_UUID",
+                    ansiblePhasesUsed: [1,3],
+                    description: "CDROM UUID",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                cdrom: {
+                    name: "cdrom",
+                    ansibleVarName: "CDROM",
+                    ansiblePhasesUsed: [1,3],
+                    description: "CDROM",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                nicUUID: {
+                    name: "nicUUID",
+                    ansibleVarName: "NIC_UUID",
+                    ansiblePhasesUsed: [1,3],
+                    description: "NIC UUID",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                consoleUUID: {
+                    name: "consoleUUID",
+                    ansibleVarName: "CONSOLE_UUID",
+                    ansiblePhasesUsed: [1],
+                    description: "Console UUID",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                videoDevice: {
+                    name: "videoDevice",
+                    ansibleVarName: "VIDEO_DEVICE",
+                    ansiblePhasesUsed: [1,3],
+                    description: "Video Device",
+                    value: "vga",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                graphicsDevice: {
+                    name: "graphicsDevice",
+                    ansibleVarName: "GRAPHICS_DEVICE",
+                    ansiblePhasesUsed: [1,3],
+                    description: "Graphics Device",
+                    value: "vnc",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                vmName: {
+                    name: "vmName",
+                    ansibleVarName: "VM_NAME",
+                    ansiblePhasesUsed: [1,3],
+                    description: "VM Name",
+                    value: "HostedEngine",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
                 }
             },
             engine: {
@@ -510,7 +815,7 @@ export class HeSetupModel {
                     type: types.STRING,
                     showInReview: true,
                     uiStage: "Engine",
-                    useInAnswerFile: false,
+                    useInAnswerFile: true,
                     required: true
                 },
                 adminUsername: {
@@ -520,7 +825,7 @@ export class HeSetupModel {
                     type: types.STRING,
                     showInReview: true,
                     uiStage: "Engine",
-                    useInAnswerFile: false,
+                    useInAnswerFile: true,
                     required: true
                 },
                 adminPassword: {
@@ -544,6 +849,30 @@ export class HeSetupModel {
                     uiStage: "Engine",
                     useInAnswerFile: false,
                     required: false
+                },
+                enableLibgfapi: {
+                    name: "enableLibgfapi",
+                    ansibleVarName: "ENABLE_LIBGFAPI",
+                    ansiblePhasesUsed: [1],
+                    description: "Enable libgfapi",
+                    value: "",
+                    type: types.BOOLEAN,
+                    showInReview: false,
+                    uiStage: "Engine",
+                    useInAnswerFile: false,
+                    required: false
+                },
+                appHostName: {
+                    name: "appHostName",
+                    ansibleVarName: "HOST_NAME",
+                    ansiblePhasesUsed: [1,2,3],
+                    description: "Host's name",
+                    value: "",
+                    type: types.STRING,
+                    showInReview: false,
+                    uiStage: "VM",
+                    useInAnswerFile: false,
+                    required: false
                 }
             },
             vdsm: {
@@ -605,6 +934,8 @@ export class HeSetupModel {
             notifications: {
                 smtpServer: {
                     name: "smtpServer",
+                    ansibleVarName: "SMTP_SERVER",
+                    ansiblePhasesUsed: [3],
                     description: "Notifications SMTP Server",
                     value: "localhost",
                     type: types.STRING,
@@ -615,6 +946,8 @@ export class HeSetupModel {
                 },
                 smtpPort: {
                     name: "smtpPort",
+                    ansibleVarName: "SMTP_PORT",
+                    ansiblePhasesUsed: [3],
                     description: "SMTP Port Number",
                     value: "25",
                     type: types.STRING,
@@ -627,6 +960,8 @@ export class HeSetupModel {
                 },
                 sourceEmail: {
                     name: "sourceEmail",
+                    ansibleVarName: "SOURCE_EMAIL",
+                    ansiblePhasesUsed: [3],
                     description: "SMTP Sender E-Mail Address",
                     value: "root@localhost",
                     type: types.STRING,
@@ -637,6 +972,8 @@ export class HeSetupModel {
                 },
                 destEmail: {
                     name: "destEmail",
+                    ansibleVarName: "DEST_EMAIL",
+                    ansiblePhasesUsed: [3],
                     description: "SMTP Recipient E-Mail Addresses",
                     value: ["root@localhost"],
                     type: types.STRING,
@@ -693,6 +1030,17 @@ export class HeSetupModel {
             })
     }
 
+    setDefaultValues(dataProvider) {
+        this.model.vm.cloudinitVMTZ.value = dataProvider.getTimeZone();
+        this.model.network.host_name.value = dataProvider.getFQDN();
+        this.model.engine.appHostName.value = dataProvider.getFQDN();
+        this.model.vm.cloudinitHostIP.value = dataProvider.getIpAddress();
+        this.model.vm.maxVCpus.value = dataProvider.getMaxVCpus();
+        if (dataProvider.getMaxMemAvailable() < constants.VM_MEM_MIN_RECOMMENDED_MB) {
+            this.model.vm.vmMemSizeMB.value = dataProvider;
+        }
+    }
+
     setBooleanValues(ansFileFields, fieldProps, desiredValue) {
         let self = this;
         ansFileFields.forEach(function(ansFileField) {
@@ -728,6 +1076,11 @@ export class HeSetupModel {
 
         return prop;
     }
+
+    assignVmUUID() {
+        const uuidv4 = require('uuid/v4');
+        this.model.vm.localVmUUID.value = uuidv4();
+    }
 }
 
 export class AnswerFileGenerator {
